Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(528)

Unified Diff: chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc

Issue 442383002: Move storage-related files from webkit/ to new top-level directory storage/ (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: . Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc
diff --git a/chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc b/chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc
index ecdfb71629ff4ffd071bd365b1c634fa9c367a80..00d9fda7cc3fc335305f49e7d4eb0d6b13f77682 100644
--- a/chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc
+++ b/chrome/browser/chromeos/file_manager/external_filesystem_apitest.cc
@@ -27,10 +27,10 @@
#include "google_apis/drive/drive_api_parser.h"
#include "google_apis/drive/test_util.h"
#include "google_apis/drive/time_util.h"
-#include "webkit/browser/fileapi/external_mount_points.h"
+#include "storage/browser/fileapi/external_mount_points.h"
// Tests for access to external file systems (as defined in
// webkit/common/fileapi/file_system_types.h) from extensions with
// fileBrowserPrivate and fileBrowserHandler extension permissions.
// The tests cover following external file system types:
// - local (kFileSystemTypeLocalNative): a local file system on which files are
@@ -408,11 +408,11 @@ class LocalFileSystemExtensionApiTest : public FileSystemExtensionApiTestBase {
// FileSystemExtensionApiTestBase OVERRIDE.
virtual void AddTestMountPoint() OVERRIDE {
- EXPECT_TRUE(content::BrowserContext::GetMountPoints(browser()->profile())->
- RegisterFileSystem(kLocalMountPointName,
- fileapi::kFileSystemTypeNativeLocal,
- fileapi::FileSystemMountOption(),
- mount_point_dir_));
+ EXPECT_TRUE(content::BrowserContext::GetMountPoints(browser()->profile())
+ ->RegisterFileSystem(kLocalMountPointName,
+ storage::kFileSystemTypeNativeLocal,
+ storage::FileSystemMountOption(),
+ mount_point_dir_));
VolumeManager::Get(browser()->profile())->AddVolumeInfoForTesting(
mount_point_dir_, VOLUME_TYPE_TESTING, chromeos::DEVICE_TYPE_UNKNOWN);
}
@@ -438,11 +438,12 @@ class RestrictedFileSystemExtensionApiTest
// FileSystemExtensionApiTestBase OVERRIDE.
virtual void AddTestMountPoint() OVERRIDE {
- EXPECT_TRUE(content::BrowserContext::GetMountPoints(browser()->profile())->
- RegisterFileSystem(kRestrictedMountPointName,
- fileapi::kFileSystemTypeRestrictedNativeLocal,
- fileapi::FileSystemMountOption(),
- mount_point_dir_));
+ EXPECT_TRUE(
+ content::BrowserContext::GetMountPoints(browser()->profile())
+ ->RegisterFileSystem(kRestrictedMountPointName,
+ storage::kFileSystemTypeRestrictedNativeLocal,
+ storage::FileSystemMountOption(),
+ mount_point_dir_));
VolumeManager::Get(browser()->profile())->AddVolumeInfoForTesting(
mount_point_dir_, VOLUME_TYPE_TESTING, chromeos::DEVICE_TYPE_UNKNOWN);
}
@@ -627,8 +628,8 @@ class LocalAndDriveFileSystemExtensionApiTest
virtual void AddTestMountPoint() OVERRIDE {
EXPECT_TRUE(content::BrowserContext::GetMountPoints(browser()->profile())
->RegisterFileSystem(kLocalMountPointName,
- fileapi::kFileSystemTypeNativeLocal,
- fileapi::FileSystemMountOption(),
+ storage::kFileSystemTypeNativeLocal,
+ storage::FileSystemMountOption(),
local_mount_point_dir_));
VolumeManager::Get(browser()->profile())
->AddVolumeInfoForTesting(local_mount_point_dir_,

Powered by Google App Engine
This is Rietveld 408576698
@@ -27,10 +27,10 @@
// Tests for access to external file systems (as defined in
-// webkit/common/fileapi/file_system_types.h) from extensions with
+// storage/common/fileapi/file_system_types.h) from extensions with
// fileBrowserPrivate and fileBrowserHandler extension permissions.
// The tests cover following external file system types: